==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebColumnLayoutDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnGroupDescriptionMetadata } from "./WebColumnGroupDescriptionMetadata";
import { WebColumnLayoutDescription } from "./WebColumnLayoutDescription";
/**
 * @hidden
 */
export let WebColumnLayoutDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnLayoutDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnLayoutDescriptionMetadata.a == null) {
                WebColumnLayoutDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnLayoutDescriptionMetadata.c(WebColumnLayoutDescriptionMetadata.a);
            }
            if (a.j(WebColumnLayoutDescriptionMetadata.a)) {
                return;
            }
            a.y(WebColumnLayoutDescriptionMetadata.a);
        }
        static c(a) {
            WebColumnGroupDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ColumnLayout");
            a.item("__tagNameWC", "String:igc-column-layout");
            a.item("__packageNameWC", "String:grids");
            a.item("__manageCollectionInMarkup", "Boolean");
            a.item("ChildrenVisibleIndexesRef", "(w:ChildrenVisibleIndexes,wf:ChildrenVisibleIndexes)DataRef:object");
        }
        static d(a) {
            WebColumnLayoutDescriptionMetadata.b(a);
            a.aa("WebColumnLayout", () => new WebColumnLayoutDescription());
            a.z("WebColumnLayout", WebColumnLayoutDescriptionMetadata.a);
        }
    }
    WebColumnLayoutDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnLayoutDescriptionMetadata, 'WebColumnLayoutDescriptionMetadata');
    WebColumnLayoutDescriptionMetadata.a = null;
    return WebColumnLayoutDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebColumnLayoutDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnGroupDescriptionMetadata } from "./WebColumnGroupDescriptionMetadata";
import { WebColumnLayoutDescription } from "./WebColumnLayoutDescription";
/**
 * @hidden
 */
export let WebColumnLayoutDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnLayoutDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnLayoutDescriptionMetadata.a == null) {
                WebColumnLayoutDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnLayoutDescriptionMetadata.c(WebColumnLayoutDescriptionMetadata.a);
            }
            if (a.k(WebColumnLayoutDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebColumnLayoutDescriptionMetadata.a);
        }
        static c(a) {
            WebColumnGroupDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ColumnLayout");
            a.item("__tagNameWC", "String:igc-column-layout");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__manageCollectionInMarkup", "Boolean");
            a.item("ChildrenVisibleIndexesRef", "(w:ChildrenVisibleIndexes,wf:ChildrenVisibleIndexes)DataRef:object");
        }
        static d(a) {
            WebColumnLayoutDescriptionMetadata.b(a);
            a.ac("WebColumnLayout", () => new WebColumnLayoutDescription());
            a.ab("WebColumnLayout", WebColumnLayoutDescriptionMetadata.a);
        }
    }
    WebColumnLayoutDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnLayoutDescriptionMetadata, 'WebColumnLayoutDescriptionMetadata');
    WebColumnLayoutDescriptionMetadata.a = null;
    return WebColumnLayoutDescriptionMetadata;
})();
